//waveform.h:

/*
 *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2011
 *
 *  This file is part of roard a part of RoarAudio,
 *  a cross-platform sound system for both, home and professional use.
 *  See README for details.
 *
 *  This file is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 3
 *  as published by the Free Software Foundation.
 *
 *  RoarAudio is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; see the file COPYING.  If not, write to
 *  the Free Software Foundation, 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 *
 */

#ifndef _WAVEFORM_H_
#define _WAVEFORM_H_

#include <roaraudio.h>

struct waveform_stream {
 int stream;
 struct roar_stream_server * ss;
};

extern struct waveform_stream g_waveform_mixer, g_waveform_recbridge;

int waveform_init  (void);
int waveform_free  (void);

int waveform_update_inputs (void);
int waveform_update_mixer  (void);

#endif

//ll
